==========
Using Salt
==========

This section describes the fundamental components and concepts that you need to understand to use Salt.

.. toctree::
    :maxdepth: 1

    grains/index
    pillar/index
    targeting/index
    mine/index
    ../ref/runners/index
    engines/index
    yaml/index
    jinja/index
    tutorials/index
    troubleshooting/index
    ../faq
    best_practices
